=======
Credits
=======

Development Lead
----------------

* David Seddon <david@seddonym.me>


Contributors
------------

- Thiago Colares https://github.com/colares
- James Cooke https://github.com/jamescooke

Other credits
-------------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _documentation: https://layer-linter.readthedocs.io
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
